==> segatex-8.500.tar.gz: segatex-8.500/src/segatex_audit2allow_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2ALLOWPROCESS_H
#define SEGATEXAUDIT2ALLOWPROCESS_H

#include <qdir.h> 

#include "segatex_audit2allow.h" 

class SegatexAudit2allow;
class SegatexAudit2whyProcess;

class SegatexAudit2allowProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexAudit2allowProcess(QWidget *parent = 0, const char *name = 0);
	SegatexAudit2whyProcess *segatex_audit2why_process;
	int i;
	QString outputfile_str_common;
public slots:
	void audit2allow_base_process(int log_file, QString outputfile_str, int options, QString moduleName_str, QString grepLineEdit_str);
signals:
	void audit2allow_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void readFromOutputFile();
	void rm_outputfile_str_common();
public:
private:
	QString outputfile_str;
	QPushButton *closeButton;
	Q3TextEdit *textEdit1;
	int a,b,c,x,y,xx,yy,xxx,yyy,xxxx,yyyy;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;

        QStringList::Iterator it_d;
        QStringList files;
	QString outputfile_str_common_real;
	QString process_command;
	QString rmcommand;

};

#endif

==> segatex-8.640.tar.gz: segatex-8.640/src/segatex_audit2allow_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2ALLOWPROCESS_H
#define SEGATEXAUDIT2ALLOWPROCESS_H

#include <QDir> 
#include <QHBoxLayout> 
#include <QVBoxLayout> 

#include "segatex_audit2allow.h" 

class SegatexAudit2allow;
class SegatexAudit2whyProcess;

class SegatexAudit2allowProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexAudit2allowProcess(QWidget *parent = 0, const char *name = 0);
	SegatexAudit2whyProcess *segatex_audit2why_process;
	int i;
	QString outputfile_str_common;
public slots:
	void audit2allow_base_process(int log_file, QString outputfile_str, int options, QString moduleName_str, QString grepLineEdit_str);
signals:
	void audit2allow_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void readFromOutputFile();
	void rm_outputfile_str_common();
public:
private:
	QString outputfile_str;
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	int a,b,c,x,y,xx,yy,xxx,yyy,xxxx,yyyy;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;

        QStringList::Iterator it_d;
        QStringList files;
	QString outputfile_str_common_real;
	QString process_command;
	QString rmcommand;
	QVBoxLayout *headLayout;
	QHBoxLayout *footLayout;
	QVBoxLayout *mainLayout;

};

#endif
